@@ -248,9 +248,7 @@ class S3ToStepFunctionProps:
         :summary:: The properties for the S3ToStepFunction Construct
         """
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(
-                **state_machine_props
-            )
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(event_rule_props, dict):
